#
# spec file for package eclipse-jgit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global gittag 5.11.0.202103091610-r
%define __provides_exclude osgi*
Name:           eclipse-jgit
Version:        5.11.0
Release:        15.2
Summary:        Eclipse JGit
License:        BSD-3-Clause
Group:          Development/Libraries/Java
URL:            https://www.eclipse.org/egit/
Source0:        https://git.eclipse.org/c/jgit/jgit.git/snapshot/jgit-%{gittag}.tar.xz
# Set the correct classpath for the command line tools
# Switch to feature requirements for third-party bundles, also makes the following changes:
#  javaewah -> com.googlecode.javaewah.JavaEWAH
#  org.slf4j.api -> slf4j.api
#  org.slf4j.impl.log4j12 -> slf4j.simple
Patch1:         0002-Don-t-embed-versions-of-third-party-libs-use-feature.patch
Patch2:         jgit-shade.patch
Patch3:         jgit-5.11.0-java8.patch
Patch4:         jgit-apache-sshd.patch
Patch5:         jgit-jsch.patch
Patch6:         jgit-CVE-2023-4759.patch
# For main build
BuildRequires:  ant
BuildRequires:  apache-commons-compress
BuildRequires:  apache-sshd >= 2.7
BuildRequires:  args4j
BuildRequires:  bouncycastle
BuildRequires:  bouncycastle-pg
BuildRequires:  bouncycastle-pkix
BuildRequires:  eclipse-platform-bootstrap
BuildRequires:  ed25519-java
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  google-gson
BuildRequires:  hamcrest
BuildRequires:  javaewah
BuildRequires:  jgit = %{version}
BuildRequires:  junit
BuildRequires:  jzlib
BuildRequires:  maven-local
BuildRequires:  slf4j
BuildRequires:  tycho
BuildRequires:  xml-commons-apis
BuildRequires:  xmvn-subst
BuildConflicts: java >= 12
BuildConflicts: java-devel >= 12
BuildConflicts: java-headless >= 12
#!BuildIgnore:  eclipse-platform
#!BuildIgnore:  tycho-bootstrap
#!BuildRequires: eclipse-emf-core eclipse-ecf-core
Requires:       apache-commons-compress
Requires:       apache-sshd >= 2.7
Requires:       args4j
Requires:       bouncycastle
Requires:       bouncycastle-pg
Requires:       bouncycastle-pkix
Requires:       ed25519-java
Requires:       google-gson
Requires:       hamcrest
Requires:       javaewah
Requires:       jgit = %{version}
Requires:       junit
Requires:       jzlib
Requires:       slf4j
Requires:       xml-commons-apis
BuildArch:      noarch
# Upstream Eclipse no longer supports non-64bit arches
ExcludeArch:    s390 %{arm} %{ix86}

%description
A pure Java implementation of the Git version control system.

%prep
%setup -q -n jgit-%{gittag}

%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1

# Disable multithreaded build
rm .mvn/maven.config

# Don't try to get deps from local *maven* repo, use tycho resolved ones
for p in $(find org.eclipse.jgit.packaging -name pom.xml) ; do
  grep -q dependencies $p && %pom_xpath_remove "pom:dependencies" $p
done

# Disable "errorprone" compiler
%pom_xpath_remove "pom:plugin[pom:artifactId='maven-compiler-plugin']/pom:configuration/pom:compilerArgs" pom.xml
%pom_xpath_remove "pom:plugin[pom:artifactId='maven-compiler-plugin']/pom:configuration/pom:annotationProcessorPaths" pom.xml

# Don't need target platform or repository modules with xmvn
%pom_disable_module org.eclipse.jgit.target org.eclipse.jgit.packaging
%pom_disable_module org.eclipse.jgit.repository org.eclipse.jgit.packaging
%pom_xpath_remove "pom:build/pom:pluginManagement/pom:plugins/pom:plugin/pom:configuration/pom:target" org.eclipse.jgit.packaging/pom.xml

# Don't build source features
%pom_disable_module org.eclipse.jgit.source.feature org.eclipse.jgit.packaging

# Don't build benchmark and coverage
%pom_disable_module org.eclipse.jgit.benchmarks
%pom_disable_module org.eclipse.jgit.coverage

# Use newer Felix dep
%pom_change_dep -r org.osgi:org.osgi.core org.osgi:osgi.core

# Remove unnecessary plugins for RPM builds
%pom_remove_plugin :jacoco-maven-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :maven-enforcer-plugin org.eclipse.jgit.packaging
%pom_remove_plugin -r :japicmp-maven-plugin

# Don't attach shell script artifact
%pom_remove_plugin org.codehaus.mojo:build-helper-maven-plugin org.eclipse.jgit.pgm

# Remove org.apache.log4j
%pom_remove_dep log4j:log4j . org.eclipse.jgit.pgm
%pom_change_dep org.slf4j:slf4j-log4j12 org.slf4j:slf4j-simple . org.eclipse.jgit.pgm

pushd org.eclipse.jgit.packaging
%{mvn_package} "::pom::" __noinstall
popd

%build
pushd org.eclipse.jgit.packaging
%{mvn_build} -j -f
popd

%install
pushd org.eclipse.jgit.packaging
%mvn_install
popd
xmvn-subst -R %{buildroot} %{_datadir}/eclipse/droplets/jgit
#%fdupes -s %{buildroot}%{_datadir}

%files -f org.eclipse.jgit.packaging/.mfiles
%license LICENSE
%doc README.md

%changelog
* Thu May 23 2024 Fridrich Strba <fstrba@suse.com>
- Require hamcrest to avoid conflict of providers with hamcrest-core
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jan 12 2024 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * jgit-apache-sshd-2.7.0.patch -> jgit-apache-sshd.patch
    + rename patch and make it accept apache-ssd < 3.0.0
* Wed Oct 11 2023 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * jgit-apache-sshd-2.7.0.patch
    + extend even more apache-sshd version span
* Tue Oct 10 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * jgit-CVE-2023-4759.patch
    + backport of upstream fix for bsc#1215298 (CVE-2023-4759),
    arbitrary file overwrite
* Fri Oct  6 2023 Fridrich Strba <fstrba@suse.com>
- Removed patch:
  * 0001-Ensure-the-correct-classpath-is-set-for-the-jgit-com.patch
    + no need to patch the jgit.sh launcher that we do not use
* Fri Oct  6 2023 Fridrich Strba <fstrba@suse.com>
- Craft the jgit script from the real Main class of the jar file
  instead of using some superfluous jar launcher.
  Fixes bsc#1209646
* Wed May 31 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * jgit-jsch.patch
    + extend the version range for the required jsch package
    + allows building with 0.2.x (which is backward compatible
    with 0.1.x)
* Fri May  5 2023 Fridrich Strba <fstrba@suse.com>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Mon Mar 27 2023 Fridrich Strba <fstrba@suse.com>
- Require xz-java because the jgit script that we install is
  expecting it to be present when composing the classpath
  (bsc#1209646)
* Wed Nov 16 2022 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * jgit-apache-sshd-2.7.0.patch
    + Allow building against apache-sshd 2.8.x and 2.9.x
* Tue Mar 29 2022 Fridrich Strba <fstrba@suse.com>
- Force building with Java 11, since tycho is not knowing about any
  Java >= 15
* Fri Jul 30 2021 Fridrich Strba <fstrba@suse.com>
- Update to 5.11.0
  * No changelog was made available.
  * fixes build against apache-sshd 2.7.0
- Modified patches:
  * 0001-Ensure-the-correct-classpath-is-set-for-the-jgit-com.patch
  * 0002-Don-t-embed-versions-of-third-party-libs-use-feature.patch
  * jgit-shade.patch
  * jgit-5.8.0-java8.patch -> jgit-5.11.0-java8.patch
    + Rediff to changed context
- Added patch:
  * jgit-apache-sshd-2.7.0.patch
    + Adapt to apache-sshd api changes between 2.6.0 and 2.7.0
- Removed patch:
  * 0003-Remove-requirement-on-assertj-core.patch
    + Not needed anymore
* Thu Nov 19 2020 Fridrich Strba <fstrba@suse.com>
- Fix provides
* Thu Jul 16 2020 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * jgit-5.8.0-java8.patch
    + restore java 8 compatibility when building with java 9+
* Fri Jul  3 2020 Fridrich Strba <fstrba@suse.com>
- Upgrade to 5.8.0
  * No changelog was made available.
- Removed patches:
  * fix_jgit_sh.patch
  * jgit-feature-deps.patch
- Added patches:
  * 0001-Ensure-the-correct-classpath-is-set-for-the-jgit-com.patch
  * 0002-Don-t-embed-versions-of-third-party-libs-use-feature.patch
  * 0003-Remove-requirement-on-assertj-core.patch
  * jgit-shade.patch
* Wed Apr  8 2020 Fridrich Strba <fstrba@suse.com>
- Split the build into two spec files instead of multibuild
  * First one produces the maven artifacts, the jgit command-line
    tool and ant feature
  * Second one produces eclipse features
* Mon Nov 11 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of eclipse-jgit 5.1.3 as a _multibuild package
  in order to allow bootstrapping
